import React from 'react';

const AddPhotos = ({ 
  projectPhotos,
  setProjectPhotos,
  projectFiles,
  setProjectFiles,
  youtubeLink,
  setYoutubeLink,
  droneViewLink,
  setDroneViewLink,
  projectMainImage,
  setProjectMainImage 
}) => {
  const handleProjectPhotoUpload = (e) => {
    const files = Array.from(e.target.files);
    setProjectPhotos((prevPhotos) => {
      // Ensure prevPhotos is an array
      const currentPhotos = Array.isArray(prevPhotos) ? prevPhotos : [];
      return [...currentPhotos, ...files];
    });

    // Optional: Update projectFiles if needed
    if (projectFiles && setProjectFiles) {
      setProjectFiles((prevFiles) => {
        const currentFiles = Array.isArray(prevFiles) ? prevFiles : [];
        return [...currentFiles, ...files];
      });
    }
  };

  const removeProjectPhoto = (index) => {
    setProjectPhotos((prevPhotos) => {
      // Ensure prevPhotos is an array before filtering
      const currentPhotos = Array.isArray(prevPhotos) ? prevPhotos : [];
      return currentPhotos.filter((_, i) => i !== index);
    });

    // Optional: Remove corresponding file from projectFiles if needed
    if (projectFiles && setProjectFiles) {
      setProjectFiles((prevFiles) => {
        const currentFiles = Array.isArray(prevFiles) ? prevFiles : [];
        return currentFiles.filter((_, i) => i !== index);
      });
    }
  };

  const handleProjectMainImageUpload = (e) => {
    const files = e.target.files;
    if (files && files.length > 0) {
      const file = files[0];
      setProjectMainImage(file);
    }
  };

  // Ensure projectPhotos is an array before using .map()
  const photoArray = Array.isArray(projectPhotos) ? projectPhotos : [];

  return (
    <div className="w-full px-4 py-6 sm:px-6 lg:px-8">
      {/* Project Photos Section */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-4 text-gray-800">Project Photos</h2>
        <div className="border-2 border-dashed border-purple-500 rounded-lg p-4 sm:p-6 flex flex-col items-center">
          <div className="flex flex-col items-center text-purple-500 mb-4">
            <svg
              xmlns="http://www.w3.org/2000/svg"
              className="h-8 w-8 sm:h-12 sm:w-12 mb-2"
              viewBox="0 0 20 20"
              fill="currentColor"
            >
              <path d="M4 3a2 2 0 00-2 2v10a2 2 0 002 2h12a2 2 0 002-2V5a2 2 0 00-2-2H4zm7 5a1 1 0 00-2 0v3H7l3 3 3-3h-2V8z" />
            </svg>
            <p className="text-sm font-medium text-center">+ Add Project Photos (Min. 5 Photos)</p>
          </div>
          <input 
            type="file" 
            multiple 
            accept="image/*" 
            onChange={handleProjectPhotoUpload}
            className="hidden" 
            id="project-photo-upload"
          />
          <label 
            htmlFor="project-photo-upload" 
            className="mt-4 bg-purple-500 text-white py-2 px-4 rounded-lg hover:bg-purple-600 cursor-pointer text-sm sm:text-base"
          >
            Upload Project Photos
          </label>
        </div>
        
        {/* Uploaded Photos Preview */}
        {photoArray.length > 0 && (
          <>
            <div className="mt-4 grid grid-cols-2 sm:grid-cols-3 md:grid-cols-4 lg:grid-cols-5 gap-2">
              {photoArray.map((photo, index) => (
                <div key={index} className="relative">
                  <img 
                    src={URL.createObjectURL(photo)} 
                    alt={`Project Photo ${index + 1}`} 
                    className="w-full h-20 sm:h-24 object-cover rounded-lg"
                  />
                  <button 
                    onClick={() => removeProjectPhoto(index)}
                    className="absolute top-1 right-1 bg-red-500 text-white rounded-full p-1 text-xs"
                  >
                    X
                  </button>
                </div>
              ))}
            </div>
            
            {/* Uploaded Photo Names */}
            <div className="mt-4">
              <h3 className="font-semibold mb-2">Uploaded Project Photo Names:</h3>
              <ul className="list-disc pl-4">
                {photoArray.map((photo, index) => (
                  <li key={index} className="text-sm text-gray-700">{photo.name}</li>
                ))}
              </ul>
            </div>
          </>
        )}
      </div>

      {/* Main Project Image Section */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-2">Main Project Image</h2>
        <input 
          type="file" 
          accept="image/*"
          onChange={handleProjectMainImageUpload}
          className="w-full bg-purple-500 text-white py-2 px-4 rounded-lg hover:bg-purple-600 file:mr-4 file:rounded-lg file:border-0 file:bg-white file:px-4 file:py-2 file:text-purple-500 text-sm sm:text-base"
        />
        
        {/* Preview for Main Image */}
        {projectMainImage && (
          <div className="mt-4 relative">
            <img 
              src={URL.createObjectURL(projectMainImage)} 
              alt="Main Project Image" 
              className="w-full h-48 object-cover rounded-lg"
            />
            <button 
              onClick={() => setProjectMainImage(null)}
              className="absolute top-1 right-1 bg-red-500 text-white rounded-full p-1 text-xs"
            >
              Remove
            </button>
          </div>
        )}
      </div>

      {/* YouTube Link Section */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-2">Project YouTube Link</h2>
        <input
          type="text"
          placeholder="Enter Project YouTube Video Link"
          value={youtubeLink || ''}
          onChange={(e) => setYoutubeLink(e.target.value)}
          className="w-full border border-purple-500 rounded-lg py-2 px-4 focus:outline-none focus:ring-2 focus:ring-purple-600 text-sm sm:text-base"
        />
      </div>

      {/* Drone View Link Section */}
      <div className="mb-6">
        <h2 className="text-lg font-semibold mb-2">Project Drone View Link</h2>
        <input
          type="text"
          placeholder="Enter Project Drone View Video Link"
          value={droneViewLink || ''}
          onChange={(e) => setDroneViewLink(e.target.value)}
          className="w-full border border-purple-500 rounded-lg py-2 px-4 focus:outline-none focus:ring-2 focus:ring-purple-600 text-sm sm:text-base"
        />
      </div>
    </div>
  );
};

export default AddPhotos;